@@ -2,6 +2,7 @@
 
 
 #include "act-user.h"
+#include "act-user-manager.h"
 #include "act-user-enum-types.h"
 #include <glib-object.h>
 
@@ -36,5 +37,21 @@ act_user_password_mode_get_type (void)
   return etype;
 }
 
+/* enumerations from "act-user-manager.h" */
+GType
+act_user_manager_error_get_type (void)
+{
+  static GType etype = 0;
+  if (etype == 0) {
+    static const GEnumValue values[] = {
+      { ACT_USER_MANAGER_ERROR_GENERAL, "ACT_USER_MANAGER_ERROR_GENERAL", "general" },
+      { ACT_USER_MANAGER_ERROR_KEY_NOT_FOUND, "ACT_USER_MANAGER_ERROR_KEY_NOT_FOUND", "key-not-found" },
+      { 0, NULL, NULL }
+    };
+    etype = g_enum_register_static ("ActUserManagerError", values);
+  }
+  return etype;
+}
+
 
 
